Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/sys/dev/ic Roll version minor.



details:   https://anonhg.NetBSD.org/src/rev/0a8f0f907924
branches:  trunk
changeset: 532784:0a8f0f907924
user:      mjacob <mjacob%NetBSD.org@localhost>
date:      Sat Jun 15 00:18:02 2002 +0000

description:
Roll version minor.

Add DEFAULT_FRAMESIZE/DEFAULT_EXEC_THROTTLE/ISPASYNC_FW_RESTARTED
defines.

diffstat:

 sys/dev/ic/ispvar.h |  17 ++++++++++++-----
 1 files changed, 12 insertions(+), 5 deletions(-)

diffs (61 lines):

diff -r 69fc3d353ef2 -r 0a8f0f907924 sys/dev/ic/ispvar.h
--- a/sys/dev/ic/ispvar.h       Sat Jun 15 00:17:28 2002 +0000
+++ b/sys/dev/ic/ispvar.h       Sat Jun 15 00:18:02 2002 +0000
@@ -1,4 +1,4 @@
-/* $NetBSD: ispvar.h,v 1.55 2002/04/04 23:38:49 mjacob Exp $ */
+/* $NetBSD: ispvar.h,v 1.56 2002/06/15 00:18:02 mjacob Exp $ */
 /*
  * This driver, which is contained in NetBSD in the files:
  *
@@ -84,7 +84,7 @@
 #endif
 
 #define        ISP_CORE_VERSION_MAJOR  2
-#define        ISP_CORE_VERSION_MINOR  6
+#define        ISP_CORE_VERSION_MINOR  7
 
 /*
  * Vector for bus specific code to provide specific services.
@@ -317,10 +317,11 @@
        struct lportdb {
                u_int32_t
                                        port_type       : 8,
-                                                       : 4,
+                                       loopid          : 8,
                                        fc4_type        : 4,
-                                       loopid          : 8,
                                        last_fabric_dev : 1,
+                                                       : 2,
+                                       relogin         : 1,
                                        force_logout    : 1,
                                        was_fabric_dev  : 1,
                                        fabric_dev      : 1,
@@ -488,6 +489,9 @@
 #define        ISP_CFG_LPORT_ONLY      0x0C    /* insist on {N/F}L-Port connection */
 #define        ISP_CFG_OWNWWPN         0x100   /* override NVRAM wwpn */
 #define        ISP_CFG_OWNWWNN         0x200   /* override NVRAM wwnn */
+#define        ISP_CFG_OWNFSZ          0x400   /* override NVRAM frame size */
+#define        ISP_CFG_OWNLOOPID       0x800   /* override NVRAM loopid */
+#define        ISP_CFG_OWNEXCTHROTTLE  0x1000  /* override NVRAM execution throttle */
 
 /*
  * Prior to calling isp_reset for the first time, the outer layer
@@ -753,7 +757,8 @@
        ISPASYNC_TARGET_ACTION,         /* other target command action */
        ISPASYNC_CONF_CHANGE,           /* Platform Configuration Change */
        ISPASYNC_UNHANDLED_RESPONSE,    /* Unhandled Response Entry */
-       ISPASYNC_FW_CRASH               /* Firmware has crashed */
+       ISPASYNC_FW_CRASH,              /* Firmware has crashed */
+       ISPASYNC_FW_RESTARTED           /* Firmware has been restarted */
 } ispasync_t;
 int isp_async(struct ispsoftc *, ispasync_t, void *);
 
@@ -882,6 +887,8 @@
  *     DEFAULT_LOOPID(struct ispsoftc *)       Default FC Loop ID
  *     DEFAULT_NODEWWN(struct ispsoftc *)      Default Node WWN
  *     DEFAULT_PORTWWN(struct ispsoftc *)      Default Port WWN
+ *     DEFAULT_FRAMESIZE(struct ispsoftc *)    Default Frame Size
+ *     DEFAULT_EXEC_THROTTLE(struct ispsoftc *) Default Execution Throttle
  *             These establish reasonable defaults for each platform.
  *             These must be available independent of card NVRAM and are
  *             to be used should NVRAM not be readable.



Home | Main Index | Thread Index | Old Index